@@ -3,7 +3,7 @@ import subprocess
 import sys
 from typing import List
 
-from termcolor_util import yellow, red
+from termcolor_util import yellow, red, green
 
 from git_monorepo.git_monorepo_config import (
     read_monorepo_config,
@@ -25,7 +25,7 @@ def pull(
     monorepo = read_monorepo_config()
 
     folders = get_folders_to_update(monorepo, folders, required)
-    validate_folders_to_update(monorepo, folders)
+    validate_folders_to_update(monorepo, folders, required)
 
     for folder_name, repo_location in monorepo.repos.items():
         if folders and not folder_name in folders:
@@ -69,16 +69,21 @@ def pull(
 def pull_monorepo_project(
     monorepo: GitMonorepoConfig, folder_name: str, repo_location: str
 ) -> None:
+    pull_command = [
+        "git",
+        "subtree",
+        "pull",
+        "-P",
+        folder_name,
+        repo_location,
+        monorepo.current_branch,
+    ]
+
+    if monorepo.squash:
+        pull_command.insert(3, "--squash")
+
     subprocess.check_call(
-        [
-            "git",
-            "subtree",
-            "pull",
-            "-P",
-            folder_name,
-            repo_location,
-            monorepo.current_branch,
-        ],
+        pull_command,
         cwd=monorepo.project_folder,
         env=env_extend(
             {
@@ -92,16 +97,21 @@ def pull_monorepo_project(
 def add_monorepo_project(
     monorepo: GitMonorepoConfig, folder_name: str, repo_location: str
 ) -> None:
+    add_command = [
+        "git",
+        "subtree",
+        "add",
+        "-P",
+        folder_name,
+        repo_location,
+        monorepo.current_branch,
+    ]
+
+    if monorepo.squash:
+        add_command.insert(3, "--squash")
+
     subprocess.check_call(
-        [
-            "git",
-            "subtree",
-            "add",
-            "-P",
-            folder_name,
-            repo_location,
-            monorepo.current_branch,
-        ],
+        add_command,
         cwd=monorepo.project_folder,
         env=env_extend(
             {
@@ -112,7 +122,9 @@ def add_monorepo_project(
     )
 
 
-def validate_folders_to_update(monorepo: GitMonorepoConfig, folders: List[str]) -> None:
+def validate_folders_to_update(
+    monorepo: GitMonorepoConfig, folders: List[str], required: bool
+) -> None:
     pull_folders = set(folders)
     pull_folders.difference_update(monorepo.repos)
     if pull_folders:
@@ -123,6 +135,10 @@ def validate_folders_to_update(monorepo: GitMonorepoConfig, folders: List[str])
         )
         sys.exit(1)
 
+    if not folders and required:
+        print(green("Nothing changed locally.", bold=True), green("Nothing to do."))
+        sys.exit(0)
+
 
 def get_folders_to_update(
     monorepo: GitMonorepoConfig, folders: List[str], required: bool
